# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delviery_shipper_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)v1/rules/delviery_shipper_warehouse.proto\x12\x34pro.omni.oms.api.v1.rules.delivery_shipper_warehouse\x1a\x11\x63ommon/base.proto"\xaa\x01\n\x18\x44\x65liveryShipperWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n%DeliveryShipperWarehouseCreateRequest\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryShipperWarehouseCreateResponse\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x81\x03\n#DeliveryShipperWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa0\x02\n$DeliveryShipperWarehouseReadResponse\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x03(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xd3\x01\n%DeliveryShipperWarehouseUpdateRequest\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryShipperWarehouseUpdateResponse\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"k\n%DeliveryShipperWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"s\n&DeliveryShipperWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9b\x07\n\x1f\x44\x65liveryShipperWarehouseService\x12\xdd\x01\n\x1e\x44\x65liveryShipperWarehouseCreate\x12[.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseCreateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseCreateResponse"\x00\x12\xd7\x01\n\x1c\x44\x65liveryShipperWarehouseRead\x12Y.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseReadRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseReadResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryShipperWarehouseUpdate\x12[.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseUpdateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseUpdateResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryShipperWarehouseDelete\x12[.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseDeleteRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delviery_shipper_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSHIPPERWAREHOUSE"]._serialized_start = 119
    _globals["_DELIVERYSHIPPERWAREHOUSE"]._serialized_end = 289
    _globals["_DELIVERYSHIPPERWAREHOUSECREATEREQUEST"]._serialized_start = 292
    _globals["_DELIVERYSHIPPERWAREHOUSECREATEREQUEST"]._serialized_end = 438
    _globals["_DELIVERYSHIPPERWAREHOUSECREATERESPONSE"]._serialized_start = 441
    _globals["_DELIVERYSHIPPERWAREHOUSECREATERESPONSE"]._serialized_end = 672
    _globals["_DELIVERYSHIPPERWAREHOUSEREADREQUEST"]._serialized_start = 675
    _globals["_DELIVERYSHIPPERWAREHOUSEREADREQUEST"]._serialized_end = 1060
    _globals["_DELIVERYSHIPPERWAREHOUSEREADRESPONSE"]._serialized_start = 1063
    _globals["_DELIVERYSHIPPERWAREHOUSEREADRESPONSE"]._serialized_end = 1351
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATEREQUEST"]._serialized_start = 1354
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATEREQUEST"]._serialized_end = 1565
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATERESPONSE"]._serialized_start = 1568
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATERESPONSE"]._serialized_end = 1799
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETEREQUEST"]._serialized_start = 1801
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETEREQUEST"]._serialized_end = 1908
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETERESPONSE"]._serialized_start = 1910
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETERESPONSE"]._serialized_end = 2025
    _globals["_DELIVERYSHIPPERWAREHOUSESERVICE"]._serialized_start = 2028
    _globals["_DELIVERYSHIPPERWAREHOUSESERVICE"]._serialized_end = 2951
# @@protoc_insertion_point(module_scope)
